"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const isBrowser = require("../functions/is-browser.qwik.cjs");
const cookie = require("./cookie.qwik.cjs");
const USER_ATTRIBUTES_COOKIE_NAME = "builder.userAttributes";
function createUserAttributesService() {
  let canTrack = true;
  const subscribers = /* @__PURE__ */ new Set();
  return {
    setUserAttributes(newAttrs) {
      if (!isBrowser.isBrowser())
        return;
      const userAttributes = {
        ...this.getUserAttributes(),
        ...newAttrs
      };
      cookie.setCookie({
        name: USER_ATTRIBUTES_COOKIE_NAME,
        value: JSON.stringify(userAttributes),
        canTrack
      });
      subscribers.forEach((callback) => callback(userAttributes));
    },
    getUserAttributes() {
      if (!isBrowser.isBrowser())
        return {};
      return JSON.parse(cookie.getCookieSync({
        name: USER_ATTRIBUTES_COOKIE_NAME,
        canTrack
      }) || "{}");
    },
    subscribeOnUserAttributesChange(callback) {
      subscribers.add(callback);
      return () => {
        subscribers.delete(callback);
      };
    },
    setCanTrack(value) {
      canTrack = value;
    }
  };
}
const userAttributesService = createUserAttributesService();
const setClientUserAttributes = (attributes) => {
  userAttributesService.setUserAttributes(attributes);
};
exports.USER_ATTRIBUTES_COOKIE_NAME = USER_ATTRIBUTES_COOKIE_NAME;
exports.createUserAttributesService = createUserAttributesService;
exports.setClientUserAttributes = setClientUserAttributes;
exports.userAttributesService = userAttributesService;
