"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const target = require("../../constants/target.qwik.cjs");
const isBrowser = require("../../functions/is-browser.qwik.cjs");
const inlinedFns = require("./inlined-fns.qwik.cjs");
const UPDATE_COOKIES_AND_STYLES_SCRIPT_NAME = "builderIoAbTest";
const UPDATE_VARIANT_VISIBILITY_SCRIPT_FN_NAME = "builderIoRenderContent";
const getVariants = (content) => Object.values((content == null ? void 0 : content.variations) || {}).map((variant) => ({
  ...variant,
  testVariationId: variant.id,
  id: content == null ? void 0 : content.id
}));
const checkShouldRenderVariants = ({ canTrack, content }) => {
  const hasVariants = getVariants(content).length > 0;
  if (!hasVariants)
    return false;
  if (!canTrack)
    return false;
  if (isBrowser.isBrowser())
    return false;
  return true;
};
const getIsHydrationTarget = (target2) => target2 === "react" || target2 === "reactNative";
const isAngularSDK = target.TARGET === "angular";
const isHydrationTarget = getIsHydrationTarget(target.TARGET);
const getInitVariantsFnsScriptString = () => `
  window.${UPDATE_COOKIES_AND_STYLES_SCRIPT_NAME} = ${inlinedFns.UPDATE_COOKIES_AND_STYLES_SCRIPT}
  window.${UPDATE_VARIANT_VISIBILITY_SCRIPT_FN_NAME} = ${inlinedFns.UPDATE_VARIANT_VISIBILITY_SCRIPT}
  `;
const getUpdateCookieAndStylesScript = (variants, contentId) => `
  window.${UPDATE_COOKIES_AND_STYLES_SCRIPT_NAME}(
    "${contentId}",${JSON.stringify(variants)}, ${isHydrationTarget}, ${isAngularSDK}
  )`;
const getUpdateVariantVisibilityScript = ({ contentId, variationId }) => `window.${UPDATE_VARIANT_VISIBILITY_SCRIPT_FN_NAME}(
    "${variationId}", "${contentId}", ${isHydrationTarget}
  )`;
exports.checkShouldRenderVariants = checkShouldRenderVariants;
exports.getInitVariantsFnsScriptString = getInitVariantsFnsScriptString;
exports.getUpdateCookieAndStylesScript = getUpdateCookieAndStylesScript;
exports.getUpdateVariantVisibilityScript = getUpdateVariantVisibilityScript;
exports.getVariants = getVariants;
