"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const target = require("../constants/target.qwik.cjs");
const omit = require("../helpers/omit.qwik.cjs");
const evaluate = require("./evaluate/evaluate.qwik.cjs");
const extractLocalizedValues = require("./extract-localized-values.qwik.cjs");
const fastClone = require("./fast-clone.qwik.cjs");
const set = require("./set.qwik.cjs");
const transformBlock = require("./transform-block.qwik.cjs");
function deepCloneWithConditions(obj) {
  if (obj === null || typeof obj !== "object")
    return obj;
  if (Array.isArray(obj))
    return obj.map((item) => deepCloneWithConditions(item));
  if (obj["@type"] === "@builder.io/sdk:Element")
    return obj;
  const clonedObj = {};
  for (const key in obj)
    if (key !== "meta" && Object.prototype.hasOwnProperty.call(obj, key))
      clonedObj[key] = deepCloneWithConditions(obj[key]);
  return clonedObj;
}
const IS_SDK_WITHOUT_CACHED_PROCESSED_BLOCK = [
  "svelte",
  "vue",
  "angular",
  "qwik",
  "solid"
].includes(target.TARGET);
const getCopy = (block) => {
  if (IS_SDK_WITHOUT_CACHED_PROCESSED_BLOCK) {
    const copy = fastClone.fastClone(block);
    const copied = {
      ...copy,
      properties: {
        ...copy.properties
      },
      actions: {
        ...copy.actions
      }
    };
    return copied;
  } else {
    const copy = deepCloneWithConditions(omit.omit(block, "children", "meta"));
    return {
      ...copy,
      properties: {
        ...copy.properties
      },
      actions: {
        ...copy.actions
      },
      children: block.children,
      meta: block.meta
    };
  }
};
const evaluateBindings = ({ block, context, localState, rootState, rootSetState }) => {
  if (!block.bindings)
    return block;
  const copied = getCopy(block);
  for (const binding in block.bindings) {
    const expression = block.bindings[binding];
    const value = evaluate.evaluate({
      code: expression,
      localState,
      rootState,
      rootSetState,
      context
    });
    set.set(copied, binding, value);
  }
  return copied;
};
function getProcessedBlock({ block, context, localState, rootState, rootSetState }) {
  let transformedBlock = extractLocalizedValues.resolveLocalizedValues(block, rootState.locale);
  transformedBlock = transformBlock.transformBlock(transformedBlock);
  return evaluateBindings({
    block: transformedBlock,
    localState,
    rootState,
    rootSetState,
    context
  });
}
exports.deepCloneWithConditions = deepCloneWithConditions;
exports.getProcessedBlock = getProcessedBlock;
